@@ -1,7 +1,7 @@
 __version_info__ = {
     'major': 1,
-    'minor': 4,
-    'micro': 2,
+    'minor': 7,
+    'micro': 1,
     'releaselevel': 'final',
     'serial': 1
 }
@@ -16,18 +16,8 @@ def get_version(short=False):
         vers.append('%s%i' % (__version_info__['releaselevel'][0], __version_info__['serial']))
     return ''.join(vers)
 
+
 __version__ = get_version()
 
 
 default_app_config = 'categories.apps.CategoriesConfig'
-
-
-def register():
-    from categories import settings
-    from categories.registration import (_process_registry, registry)
-    _process_registry(settings.FK_REGISTRY, registry.register_fk)
-    _process_registry(settings.M2M_REGISTRY, registry.register_m2m)
-try:
-    register()
-except Exception as e:
-    print(e)
