@@ -1,7 +1,7 @@
 """
 These functions handle the adding of fields to other models
 """
-from django.db.models import FieldDoesNotExist, ForeignKey, ManyToManyField
+from django.db.models import FieldDoesNotExist, ForeignKey, ManyToManyField, CASCADE
 from . import fields
 # from settings import self._field_registry, self._model_registry
 from django.utils.translation import ugettext_lazy as _
@@ -62,6 +62,7 @@ class Registry(object):
         for fld in field_definitions:
             extra_params = {'to': 'categories.Category', 'blank': True}
             if field_type != 'ManyToManyField':
+                extra_params['on_delete'] = CASCADE
                 extra_params['null'] = True
             if isinstance(fld, str):
                 field_name = fld
@@ -110,6 +111,7 @@ class Registry(object):
             self._field_registry[registry_name] = field(**extra_params)
             self._field_registry[registry_name].contribute_to_class(model, field_name)
 
+
 registry = Registry()
 
 
